pub enum Attribute {
Show 13 variants
Opaque,
Exclude,
Rename(String),
VariantsPrefix(String),
VariantsSuffix(String),
Transparent,
IsPrecondition(ItemId),
IsPostcondition(ItemId),
HasPrecondition(FunDeclId),
HasPostcondition(FunDeclId),
DocComment(String),
Builtin(AttributeKind),
Unknown(RawAttribute),
}Expand description
Attributes (#[...]).
Variants
Opaque
Do not translate the body of this item.
Written #[charon::opaque]
Exclude
Do not translate this item at all.
Written #[charon::exclude]
Rename(String)
Provide a new name that consumers of the llbc can use.
Written #[charon::rename("new_name")]
VariantsPrefix(String)
For enums only: rename the variants by pre-pending their names with the given prefix.
Written #[charon::variants_prefix("prefix_")].
VariantsSuffix(String)
Same as VariantsPrefix, but appends to the name instead of pre-pending.
Transparent
The structure is treated as a transparent wrapper around its sole field.
Written #[charon::transparent].
IsPrecondition(ItemId)
An item annotated with #[charon::precondition]. This makes it a precondition for its
parent item.
IsPostcondition(ItemId)
An item annotated with #[charon::postcondition]. This makes it a postcondition for its
parent item.
HasPrecondition(FunDeclId)
An item that has a precondition that applies to it. The referenced item is a function the specifies the condition.
HasPostcondition(FunDeclId)
An item that has a postcondition that applies to it. The referenced item is a function the specifies the condition.
DocComment(String)
A doc-comment such as /// ....
Builtin(AttributeKind)
A built-in attribute.
Unknown(RawAttribute)
None of the above.
Implementations
Sourceimpl Attribute
impl Attribute
pub fn is_opaque(&self) -> bool
pub fn is_exclude(&self) -> bool
pub fn is_rename(&self) -> bool
pub fn is_variants_prefix(&self) -> bool
pub fn is_variants_suffix(&self) -> bool
pub fn is_transparent(&self) -> bool
pub fn is_is_precondition(&self) -> bool
pub fn is_is_postcondition(&self) -> bool
pub fn is_has_precondition(&self) -> bool
pub fn is_has_postcondition(&self) -> bool
pub fn is_doc_comment(&self) -> bool
pub fn is_builtin(&self) -> bool
pub fn is_unknown(&self) -> bool
Sourceimpl Attribute
impl Attribute
pub fn as_opaque(&self) -> Option<()>
pub fn as_exclude(&self) -> Option<()>
pub fn as_rename(&self) -> Option<&String>
pub fn as_variants_prefix(&self) -> Option<&String>
pub fn as_variants_suffix(&self) -> Option<&String>
pub fn as_transparent(&self) -> Option<()>
pub fn as_is_precondition(&self) -> Option<&ItemId>
pub fn as_is_postcondition(&self) -> Option<&ItemId>
pub fn as_has_precondition(&self) -> Option<&FunDeclId>
pub fn as_has_postcondition(&self) -> Option<&FunDeclId>
pub fn as_doc_comment(&self) -> Option<&String>
pub fn as_builtin(&self) -> Option<&AttributeKind>
pub fn as_unknown(&self) -> Option<&RawAttribute>
Sourceimpl Attribute
impl Attribute
pub fn as_opaque_mut(&mut self) -> Option<()>
pub fn as_exclude_mut(&mut self) -> Option<()>
pub fn as_rename_mut(&mut self) -> Option<&mut String>
pub fn as_variants_prefix_mut(&mut self) -> Option<&mut String>
pub fn as_variants_suffix_mut(&mut self) -> Option<&mut String>
pub fn as_transparent_mut(&mut self) -> Option<()>
pub fn as_is_precondition_mut(&mut self) -> Option<&mut ItemId>
pub fn as_is_postcondition_mut(&mut self) -> Option<&mut ItemId>
pub fn as_has_precondition_mut(&mut self) -> Option<&mut FunDeclId>
pub fn as_has_postcondition_mut(&mut self) -> Option<&mut FunDeclId>
pub fn as_doc_comment_mut(&mut self) -> Option<&mut String>
pub fn as_builtin_mut(&mut self) -> Option<&mut AttributeKind>
pub fn as_unknown_mut(&mut self) -> Option<&mut RawAttribute>
Sourceimpl Attribute
impl Attribute
pub fn to_opaque(self) -> Option<()>
pub fn to_exclude(self) -> Option<()>
pub fn to_rename(self) -> Option<String>
pub fn to_variants_prefix(self) -> Option<String>
pub fn to_variants_suffix(self) -> Option<String>
pub fn to_transparent(self) -> Option<()>
pub fn to_is_precondition(self) -> Option<ItemId>
pub fn to_is_postcondition(self) -> Option<ItemId>
pub fn to_has_precondition(self) -> Option<FunDeclId>
pub fn to_has_postcondition(self) -> Option<FunDeclId>
pub fn to_doc_comment(self) -> Option<String>
pub fn to_builtin(self) -> Option<AttributeKind>
pub fn to_unknown(self) -> Option<RawAttribute>