pub enum ItemOpacity {
Transparent,
Foreign,
Opaque,
Invisible,
}Expand description
How much to translate for a given item.
Variants
Transparent
Translate the item fully.
Foreign
Translate the item depending on the normal rust visibility of its contents: for types, we
translate fully if it is a struct with public fields or an enum; for other items this is
equivalent to Opaque.
Opaque
Translate the item name and signature, but not its contents. For function and globals, this means we don’t translate the body (the code); for ADTs, this means we don’t translate the fields/variants. For traits and trait impls, this doesn’t change anything. For modules, this means we don’t explore its contents (we still translate any of its items mentioned from somewhere else).
This can happen either if the item was annotated with #[charon::opaque] or if it was
declared opaque via a command-line argument.
Invisible
Translate nothing of this item. The corresponding map will not have an entry for the
ItemId. Useful when even the signature of the item causes errors.
Implementations
Sourceimpl ItemOpacity
impl ItemOpacity
pub fn is_transparent(&self) -> bool
pub fn is_foreign(&self) -> bool
pub fn is_opaque(&self) -> bool
pub fn is_invisible(&self) -> bool
Sourceimpl ItemOpacity
impl ItemOpacity
pub fn with_content_visibility(self, contents_are_public: bool) -> Self
pub fn with_private_contents(self) -> Self