pub struct AttrInfo {
pub attributes: Vec<Attribute>,
pub inline: Option<InlineAttr>,
pub rename: Option<String>,
pub public: bool,
}Expand description
Information about the attributes and visibility of an item, field or variant..
Fields
attributes: Vec<Attribute>Attributes (#[...]).
inline: Option<InlineAttr>Inline hints (on functions only).
rename: Option<String>The name computed from charon::rename and charon::variants_prefix attributes, if any.
This provides a custom name that can be used by consumers of llbc. E.g. Aeneas uses this to
rename definitions in the extracted code.
public: boolWhether this item is declared public. Impl blocks and closures don’t have visibility
modifiers; we arbitrarily set this to false for them.
Note that this is different from being part of the crate’s public API: to be part of the public API, an item has to also be reachable from public items in the crate root. For example:
mod foo {
pub struct X;
}
mod bar {
pub fn something(_x: super::foo::X) {}
}
pub use bar::something; // exposes `X`Without the pub use ..., neither X nor something would be part of the crate’s public
API (this is called “pub-in-priv” items). With or without the pub use, we set public = true; computing item reachability is harder.
Implementations
Sourceimpl AttrInfo
impl AttrInfo
pub fn dummy_private() -> Self
pub fn dummy_public() -> Self